﻿/*　置換設定ファイルを読み込んで連続置換するスクリプト（新字→旧字等の文字置換用）
	置換設定ファイルはTab区切りテキストで
		検索文字列	置換文字列	字形	OpenTypeFeatures
	の形になっていること。
例

卿	卿	エキスパート字形
逢	逢	なし	["jp04",1]
龍	龍	なし	["aalt",3]

		2008.12.17 by MishimaBaikamo
*/

main();

function main(){
	var filename = File.openDialog("開く置換設定ファイルを指定してください","ChangeTextTable.txt");
	if (filename){
		var fileObj = new File(filename);
		if (fileObj.open("r")){
			var ctTable = new Array();
			try {
				for (var i = 0; !fileObj.eof; i++) ctTable[i] = fileObj.readln();
			} catch(e) {
				alert("ファイルの読み込みに失敗しました。"); return;
			}
			fileObj.close();
		} else {
			alert("ファイルを開けませんでした。"); return;
		}
		var IDversion = app.version;
		if (IDversion[0] == "4"){ //InDesign CS2
			var CS2flag = true;
		} else if (IDversion[0] >= "5"){ //InDesign CS3~
			var CS2flag = false;
		} else {
			alert("このバージョンのInDesignでは実行できません。"); return;
		}
		var range = app.activeDocument; //置換範囲はドキュメント全体
		//var range = app.selection[0].parentStory;	//置換範囲は文字キャレットのある親ストーリー
		// 検索・置換機能を使用するので、それらを退避しておく
		if (CS2flag){ //CS2
			var findPreferencesOld = app.findPreferences.properties;
			var changePreferencesOld = app.changePreferences.properties;
			app.findPreferences = 1851876449; //NothingEnum.nothing;
			app.changePreferences = 1851876449; //NothingEnum.nothing;
		 } else { //CS3~
			var findTextPreferencesOld = app.findTextPreferences.properties;
			var changeTextPreferencesOld = app.changeTextPreferences.properties;
			var findChangeTextOptionsOld = app.findChangeTextOptions.properties;
			app.findTextPreferences = 1851876449; //NothingEnum.nothing;
			app.changeTextPreferences = 1851876449; //NothingEnum.nothing;
			app.findChangeTextOptions = 1851876449; //NothingEnum.nothing;
		}
		for (var i=0; i<ctTable.length; i++){
			changeTextFunction(ctTable[i],range,CS2flag);
		}
		// 退避しておいた検索・置換の設定を復帰
		if (CS2flag){ //CS2
			app.findPreferences.properties = findPreferencesOld;
			app.changePreferences.properties = changePreferencesOld;
			if (app.findPreferences.kerningMethod=="None") app.findPreferences.kerningMethod = 1851876449;
			if (app.changePreferences.kerningMethod=="None") app.changePreferences.kerningMethod = 1851876449;
		} else { //CS3~
			app.findTextPreferences.properties = findTextPreferencesOld;
			app.changeTextPreferences.properties = changeTextPreferencesOld;
			app.findChangeTextOptions.properties = findChangeTextOptionsOld;
			if (app.findTextPreferences.kerningMethod=="None") app.findTextPreferences.kerningMethod = 1851876449;
			if (app.changeTextPreferences.kerningMethod=="None") app.changeTextPreferences.kerningMethod = 1851876449;
		}
	} else {
		alert("キャンセルされました。"); return;
	}
}

function changeTextFunction(ctTable,range,CS2flag){
	TAB = String.fromCharCode(0x09); //タブ
	var ct = ctTable.split(TAB);
	if (CS2flag){ //CS2
		app.findPreferences.findText = ct[0];
		app.changePreferences.changeText = ct[1];
		app.changePreferences.glyphForm = glyphFormFunction(ct[2]);
		var replace_Texts = range.search(app.findPreferences.findText, undefined, undefined, undefined, undefined, app.changePreferences.changeText);
		app.changePreferences = 1851876449; //NothingEnum.nothing;
	} else { //CS3~
		app.findTextPreferences.findWhat = ct[0];
		app.changeTextPreferences.changeTo = ct[1];
		app.changeTextPreferences.glyphForm = glyphFormFunction(ct[2]);
		var replace_Texts = range.changeText();
		app.changeTextPreferences = 1851876449; //NothingEnum.nothing;
	}
	if (ct[3] != "" && ct[3] != undefined){
		for (var j=0; j<replace_Texts.length; j++){
			replace_Texts[j].opentypeFeatures = eval("["+ct[3]+"]");
		}
	}
}

function glyphFormFunction(str){
	switch (str){
		case "エキスパート字形":	 return 1247897445; //AlternateGlyphForms.EXPERT_FORM
		case "等幅全角字形":		 return 1247897446; //AlternateGlyphForms.FULL_WIDTH_FORM
		case "JIS2004字形": case "JIS 2004 字形":case "JIS 04 字形":
		case "JIS04字形": 		return 1247897396; //AlternateGlyphForms.JIS04_FORM
		case "JIS 78 字形":
		case "JIS78字形": 		return 1247897399; //AlternateGlyphForms.JIS78_FORM
		case "JIS 83 字形":
		case "JIS83字形": 		return 1247897400; //AlternateGlyphForms.JIS83_FORM
		case "JIS 90 字形":
		case "JIS90字形": 		return 1247897401; //AlternateGlyphForms.JIS90_FORM
		case "等幅半角字形": 	return 1247897453; //AlternateGlyphForms.MONOSPACED_HALF_WIDTH_FORM
		case "印刷標準字形":		return 1247897454; //AlternateGlyphForms.NLC_FORM
		case "標準字形": case "標準字形に戻す":
		case "なし": 				return 1852796517; //AlternateGlyphForms.NONE
		case "プロポーショナル字形": return 1247897456; //AlternateGlyphForms.PROPORTIONAL_WIDTH_FORM
		case "等幅４分字形":
		case "等幅4分字形": 		return 1247897457; //AlternateGlyphForms.QUARTER_WIDTH_FORM
		case "等幅３分字形":
		case "等幅3分字形": 		return 1247897448; //AlternateGlyphForms.THIRD_WIDTH_FORM
		case "旧字体": 			return 1247897460; //AlternateGlyphForms.TRADITIONAL_FORM
		default : return 1852796517;
	}
}